/*
 * Sudoku Solver Copyright (C) 2005 Keith Flanagan
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307 USA
 */
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.io.IOException;

import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JOptionPane;
import javax.swing.JToolBar;

/**
 * A toolbar containing buttons for accessing the features of this program,
 * including: saving, loading, and solving puzzles
 * 
 * @author Keith Flanagan
 */
public class SudokuToolbox extends JToolBar
{
  /**
   * Reference to the main program. Used for obtaining loaded grids, storing
   * solved grids.
   */
//  private JButton createGridButton;

  private JButton loadGridButton;

  private JButton saveGridButton;

  private JButton solveButton;

  private File lastUsedDirectory;

  public SudokuToolbox(final Sudoku sudoku)
  {
//    createGridButton = new JButton("Create puzzle");
//    createGridButton.addActionListener(new ActionListener() {
//      public void actionPerformed(ActionEvent e)
//      {
//        new NewGridDialogue(sudoku.getOwner()).setVisible(true);
//      }
//    });
    loadGridButton = new JButton("Load...");
    loadGridButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e)
      {
        JFileChooser fileDialogue;
        if (lastUsedDirectory == null) {
          fileDialogue = new JFileChooser();
        } else {
          fileDialogue = new JFileChooser(lastUsedDirectory);
        }
        if (fileDialogue.showOpenDialog(sudoku) == JFileChooser.APPROVE_OPTION) {
          File file = fileDialogue.getSelectedFile();
          lastUsedDirectory = file.getParentFile();
          try {
            byte[][] grid = GridFiler.loadGrid(file);
            sudoku.setCurrentGrid(grid);
          }
          catch (ParseDataException ee) {
            JOptionPane.showMessageDialog(sudoku.getParent(),
                "Error loading file " + file.getName());
          }
        }
      }
    });
    saveGridButton = new JButton("Save...");
    saveGridButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e)
      {
        JFileChooser fileDialogue;
        if (lastUsedDirectory == null) {
          fileDialogue = new JFileChooser();
        } else {
          fileDialogue = new JFileChooser(lastUsedDirectory);
        }
        if (fileDialogue.showSaveDialog(sudoku) == JFileChooser.APPROVE_OPTION) {
          File file = fileDialogue.getSelectedFile();
          lastUsedDirectory = file.getParentFile();
          try {
            GridFiler.saveGrid(file, sudoku.getCurrentGrid());
          }
          catch (IOException ee) {
            JOptionPane.showMessageDialog(sudoku.getParent(),
                "Error saving file " + file.getName());
          }
        }
      }
    });
    solveButton = new JButton("Solve");
    solveButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e)
      {
        try {
          sudoku.solve();
        }
        catch (InvalidGridException ge) {

        }
      }
    });

//    add(createGridButton);
    add(loadGridButton);
    add(saveGridButton);
    add(solveButton);
  }
}